summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteonlinestatus.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteonlinestatus.h')
-rw-r--r--kopete/libkopete/kopeteonlinestatus.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kopete/libkopete/kopeteonlinestatus.h b/kopete/libkopete/kopeteonlinestatus.h
index 2eed5164..8136b1da 100644
--- a/kopete/libkopete/kopeteonlinestatus.h
+++ b/kopete/libkopete/kopeteonlinestatus.h
@@ -26,7 +26,7 @@
#include <kdemacros.h>
#include <ksharedptr.h>
-#include <qobject.h>
+#include <tqobject.h>
class QString;
class QPixmap;
@@ -169,13 +169,13 @@ public:
* by libkopete and should be unique per protocol.
* @param overlayIcons is a list of QStrings which are the name of status
* icons to be used by the KDE icon loader. (Statuses which don't have icons
* to overlay like Online and Offline should use QString::null as icon
* name ). NOTE if the string is a movie ( *.mng ) it must be the first string in the list.
* TODO: KDE4 sort out movies and overlay icons.
* @param description is a description in e.g. tooltips.
*/
OnlineStatus( StatusType status, unsigned weight, Protocol *protocol,
- unsigned internalStatus, const QStringList &overlayIcons, const QString &description );
+ unsigned internalStatus, const TQStringList &overlayIcons, const TQString &description );
/**
* Constructor.
@@ -203,15 +203,15 @@ public:
* by libkopete and should be unique per protocol.
* @param overlayIcon is a string returning the name of the status icon to be
* used by the KDE icon loader. (Status whiwh doesn't have icon to overlay like
* Online and Offline should use QString::null as icon string)
* @param description is a description in e.g. tooltips.
* @param caption is the text of the action in the menu
* @param categories the categories this online status is in
* @param options the options of this online status
* @see Kopete::OnlineStatusManager::registerOnlineStatus for more info about the categories and options parameters
*/
- OnlineStatus( StatusType status, unsigned weight, Protocol *protocol, unsigned internalStatus, const QStringList &overlayIcon,
- const QString &description, const QString& caption, unsigned int categories=0x0 , unsigned int options=0x0 );
+ OnlineStatus( StatusType status, unsigned weight, Protocol *protocol, unsigned internalStatus, const TQStringList &overlayIcon,
+ const TQString &description, const TQString& caption, unsigned int categories=0x0 , unsigned int options=0x0 );
/**
@@ -254,12 +254,12 @@ public:
/**
* \brief Return the list of overlay icons
*/
- QStringList overlayIcons() const;
+ TQStringList overlayIcons() const;
/**
* \brief Return the description
*/
- QString description() const;
+ TQString description() const;
/**
* \brief Return the protocol this applies to
@@ -283,7 +283,7 @@ public:
* @param contact is the contact the icon should apply to.
* @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
*/
- QPixmap iconFor( const Contact *contact, int size = 16 ) const;
+ TQPixmap iconFor( const Contact *contact, int size = 16 ) const;
/**
* \brief Return the mime source for a status icon generated for the given Contact
@@ -297,7 +297,7 @@ public:
* @param contact is the contact the icon should apply to.
* @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
*/
- QString mimeSourceFor( const Contact *contact, int size = 16 ) const;
+ TQString mimeSourceFor( const Contact *contact, int size = 16 ) const;
/**
* \brief Return a status icon generated for the given Account
@@ -307,10 +307,10 @@ public:
* over the base icon.
* A cache is employed to reduce CPU and memory usage.
* @param account is the account the icon should apply to.
* The account's color causes tinting, if it's plain QColor(), no tinting takes place.
* @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
*/
- QPixmap iconFor( const Account *account, int size = 16 ) const;
+ TQPixmap iconFor( const Account *account, int size = 16 ) const;
/**
* \brief Return the mime source for a status icon generated for the given Account
@@ -322,10 +322,10 @@ public:
* so no assumptions should be made about long-time availability
* of the referenced data.
* @param account is the account the icon should apply to.
* The account's color causes tinting, if it's plain QColor(), no tinting takes place.
* @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
*/
- QString mimeSourceFor( const Account *account, int size = 16 ) const;
+ TQString mimeSourceFor( const Account *account, int size = 16 ) const;
/**
* \brief Return a previously rendered status icon for a mime source key
@@ -336,14 +336,14 @@ public:
* requesting the key (thus rendering the icon) and trying to access the
* icon by key, an invalid pixmap will be returned.
*/
- QPixmap iconFor( const QString &mimeSource ) const;
+ TQPixmap iconFor( const TQString &mimeSource ) const;
/**
* \brief Returns the status icon for the protocol.
*
* A cache is employed to reduce CPU and memory usage.
*/
- QPixmap protocolIcon() const;
+ TQPixmap protocolIcon() const;
/**
* Assignment operator
@@ -381,20 +381,20 @@ public:
bool operator<( const OnlineStatus &other ) const;
/**
* \brief returns a QString from a StatusType
*
* Static method to convert a Kopete::OnlineStatus::StatusType to a string to avoid
* many issues when saving StatusType to disk
*/
- static QString statusTypeToString(OnlineStatus::StatusType status);
+ static TQString statusTypeToString(OnlineStatus::StatusType status);
/**
* \brief returns a StatusType from a QString
*
* Static method to convert a QString representing a StatusType to a StatusType to avoid
* many issues when saving StatusType to disk
*/
- static OnlineStatus::StatusType statusStringToType(QString& string);
+ static OnlineStatus::StatusType statusStringToType(TQString& string);
@@ -403,7 +403,7 @@ private:
class Private;
KSharedPtr<Private> d;
- QString mimeSource( const QString& icon, int size, QColor color, bool idle) const;
+ TQString mimeSource( const TQString& icon, int size, TQColor color, bool idle) const;
};
@@ -169,13 +169,13 @@ public:
* @param overlayIcons is a list of QStrings which are the name of status
* icons to be used by the KDE icon loader. (Statuses which don't have icons
- * to overlay like Online and Offline should use QString::null as icon
+ * to overlay like Online and Offline should use TQString::null as icon
* name ). NOTE if the string is a movie ( *.mng ) it must be the first string in the list.
* TODO: KDE4 sort out movies and overlay icons.
@@ -203,15 +203,15 @@ public:
* @param overlayIcon is a string returning the name of the status icon to be
* used by the KDE icon loader. (Status whiwh doesn't have icon to overlay like
- * Online and Offline should use QString::null as icon string)
+ * Online and Offline should use TQString::null as icon string)
* @param description is a description in e.g. tooltips.
* @param caption is the text of the action in the menu
@@ -307,10 +307,10 @@ public:
* A cache is employed to reduce CPU and memory usage.
* @param account is the account the icon should apply to.
- * The account's color causes tinting, if it's plain QColor(), no tinting takes place.
+ * The account's color causes tinting, if it's plain TQColor(), no tinting takes place.
* @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
*/
@@ -322,10 +322,10 @@ public:
* of the referenced data.
* @param account is the account the icon should apply to.
- * The account's color causes tinting, if it's plain QColor(), no tinting takes place.
+ * The account's color causes tinting, if it's plain TQColor(), no tinting takes place.
* @param size is the size we the icon should be scaled to - 16 is default and so costs nothing
*/
@@ -381,20 +381,20 @@ public:
bool operator<( const OnlineStatus &other ) const;
/**
- * \brief returns a QString from a StatusType
+ * \brief returns a TQString from a StatusType
*
* Static method to convert a Kopete::OnlineStatus::StatusType to a string to avoid
@@ -381,20 +381,20 @@ public:
* \brief returns a StatusType from a QString
*
- * Static method to convert a QString representing a StatusType to a StatusType to avoid
+ * Static method to convert a TQString representing a StatusType to a StatusType to avoid
* many issues when saving StatusType to disk
*/